@@ -134,11 +134,12 @@ class MLDL:
             main_thread = executor.submit(self.fetch_sample_main, index_list, collections[MAIN])
             interaction_thread = executor.submit(self.fetch_sample_interaction, index_list, collections[INTERACTION])
 
-        main_df = main_thread.result()
-        interaction_df = interaction_thread.result()
-
-        return pd.merge(main_df, interaction_df, on='row_id', how='left')
+            main_df = main_thread.result()
+            interaction_df = interaction_thread.result()
+            print(main_df.columns, interaction_df.columns)
 
+            return pd.merge(main_df, interaction_df, on='row_id', how='left')
+        print('WHAAAT')
     def fetch_sample_main(self, index_list, col):
         """
         This function is used to fetch the main data from the database
@@ -146,7 +147,7 @@ class MLDL:
         :param col: main collection
         :return: dataframe of main data
         """
-        cursor = col.find({'row_id': {'$in': index_list}}, {'row_id': 1, 'sequence': 1, 'token_ids': 1})
+        cursor = col.find({'row_id': {'$in': index_list}}, {'_id': 0, 'row_id': 1, 'sequence': 1, 'token_ids': 1})
         return pd.DataFrame(list(cursor))
 
     def fetch_sample_interaction(self, index_list, col):
@@ -156,7 +157,7 @@ class MLDL:
         :param col: interaction collection
         :return: dataframe of interaction data
         """
-        cursor = col.find({'row_id': {'$in': index_list}}, {'row_id': 1, 'interactions': 1})
+        cursor = col.find({'row_id': {'$in': index_list}}, {'_id': 0, 'row_id': 1, 'interactions': 1})
         return pd.DataFrame(list(cursor))
 
     def background_sample_cache(self, max_length, num, min_num_feature, col):
